@@ -47,6 +47,7 @@ macro_rules! command_list {
     count       Count records
     dedup       Remove redundant rows
     enum        Add a new column enumerating CSV lines
+    excel       Exports an Excel sheet to a CSV
     exclude     Excludes the records in one CSV from another
     explode     Explode rows based on some column separator
     fetch*      Create a new column or fetch values from a URL column/template
@@ -226,6 +227,7 @@ enum Command {
     Count,
     Dedup,
     Enum,
+    Excel,
     Exclude,
     Explode,
     #[cfg(all(feature = "fetch", not(feature = "lite")))]
@@ -289,6 +291,7 @@ impl Command {
             Command::Count => cmd::count::run(argv),
             Command::Dedup => cmd::dedup::run(argv),
             Command::Enum => cmd::enumerate::run(argv),
+            Command::Excel => cmd::excel::run(argv),
             Command::Exclude => cmd::exclude::run(argv),
             Command::Explode => cmd::explode::run(argv),
             #[cfg(all(feature = "fetch", not(feature = "lite")))]
